==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGenericOpenGLRenderWindow.java <==
// java wrapper for vtkGenericOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkGenericOpenGLRenderWindow extends vtkOpenGLRenderWindow
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Frame_3();
  public void Frame()
    { Frame_3(); }

  private native void MakeCurrent_4();
  public void MakeCurrent()
    { MakeCurrent_4(); }

  private native boolean IsCurrent_5();
  public boolean IsCurrent()
    { return IsCurrent_5(); }

  private native int SupportsOpenGL_6();
  public int SupportsOpenGL()
    { return SupportsOpenGL_6(); }

  private native int IsDirect_7();
  public int IsDirect()
    { return IsDirect_7(); }

  private native void SetFrontBuffer_8(int id0);
  public void SetFrontBuffer(int id0)
    { SetFrontBuffer_8(id0); }

  private native void SetFrontLeftBuffer_9(int id0);
  public void SetFrontLeftBuffer(int id0)
    { SetFrontLeftBuffer_9(id0); }

  private native void SetFrontRightBuffer_10(int id0);
  public void SetFrontRightBuffer(int id0)
    { SetFrontRightBuffer_10(id0); }

  private native void SetBackBuffer_11(int id0);
  public void SetBackBuffer(int id0)
    { SetBackBuffer_11(id0); }

  private native void SetBackLeftBuffer_12(int id0);
  public void SetBackLeftBuffer(int id0)
    { SetBackLeftBuffer_12(id0); }

  private native void SetBackRightBuffer_13(int id0);
  public void SetBackRightBuffer(int id0)
    { SetBackRightBuffer_13(id0); }

  private native void PushState_14();
  public void PushState()
    { PushState_14(); }

  private native void PopState_15();
  public void PopState()
    { PopState_15(); }

  private native void SetWindowInfo_16(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_16(id0); }

  private native void SetParentInfo_17(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_17(id0); }

  private native int[]  GetScreenSize_18();
  public int[]  GetScreenSize()
    { return GetScreenSize_18(); }

  private native void Start_19();
  public void Start()
    { Start_19(); }

  private native void HideCursor_20();
  public void HideCursor()
    { HideCursor_20(); }

  private native void ShowCursor_21();
  public void ShowCursor()
    { ShowCursor_21(); }

  private native void SetFullScreen_22(int id0);
  public void SetFullScreen(int id0)
    { SetFullScreen_22(id0); }

  private native void WindowRemap_23();
  public void WindowRemap()
    { WindowRemap_23(); }

  private native int GetEventPending_24();
  public int GetEventPending()
    { return GetEventPending_24(); }

  private native void SetNextWindowInfo_25(String id0);
  public void SetNextWindowInfo(String id0)
    { SetNextWindowInfo_25(id0); }

  private native void CreateAWindow_26();
  public void CreateAWindow()
    { CreateAWindow_26(); }

  private native void DestroyWindow_27();
  public void DestroyWindow()
    { DestroyWindow_27(); }

  private native void SetIsDirect_28(int id0);
  public void SetIsDirect(int id0)
    { SetIsDirect_28(id0); }

  private native void SetSupportsOpenGL_29(int id0);
  public void SetSupportsOpenGL(int id0)
    { SetSupportsOpenGL_29(id0); }

  private native void SetIsCurrent_30(boolean id0);
  public void SetIsCurrent(boolean id0)
    { SetIsCurrent_30(id0); }

  public vtkGenericOpenGLRenderWindow() { super(); }

  public vtkGenericOpenGLRenderWindow(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkGenericOpenGLRenderWindow.java <==
// java wrapper for vtkGenericOpenGLRenderWindow object
//

package vtk;
import vtk.*;

public class vtkGenericOpenGLRenderWindow extends vtkOpenGLRenderWindow
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Frame_3();
  public void Frame()
    { Frame_3(); }

  private native void MakeCurrent_4();
  public void MakeCurrent()
    { MakeCurrent_4(); }

  private native boolean IsCurrent_5();
  public boolean IsCurrent()
    { return IsCurrent_5(); }

  private native int SupportsOpenGL_6();
  public int SupportsOpenGL()
    { return SupportsOpenGL_6(); }

  private native int IsDirect_7();
  public int IsDirect()
    { return IsDirect_7(); }

  private native void SetFrontBuffer_8(int id0);
  public void SetFrontBuffer(int id0)
    { SetFrontBuffer_8(id0); }

  private native void SetFrontLeftBuffer_9(int id0);
  public void SetFrontLeftBuffer(int id0)
    { SetFrontLeftBuffer_9(id0); }

  private native void SetFrontRightBuffer_10(int id0);
  public void SetFrontRightBuffer(int id0)
    { SetFrontRightBuffer_10(id0); }

  private native void SetBackBuffer_11(int id0);
  public void SetBackBuffer(int id0)
    { SetBackBuffer_11(id0); }

  private native void SetBackLeftBuffer_12(int id0);
  public void SetBackLeftBuffer(int id0)
    { SetBackLeftBuffer_12(id0); }

  private native void SetBackRightBuffer_13(int id0);
  public void SetBackRightBuffer(int id0)
    { SetBackRightBuffer_13(id0); }

  private native void PushState_14();
  public void PushState()
    { PushState_14(); }

  private native void PopState_15();
  public void PopState()
    { PopState_15(); }

  private native void SetWindowInfo_16(String id0);
  public void SetWindowInfo(String id0)
    { SetWindowInfo_16(id0); }

  private native void SetParentInfo_17(String id0);
  public void SetParentInfo(String id0)
    { SetParentInfo_17(id0); }

  private native int[]  GetScreenSize_18();
  public int[]  GetScreenSize()
    { return GetScreenSize_18(); }

  private native void Start_19();
  public void Start()
    { Start_19(); }

  private native void HideCursor_20();
  public void HideCursor()
    { HideCursor_20(); }

  private native void ShowCursor_21();
  public void ShowCursor()
    { ShowCursor_21(); }

  private native void SetFullScreen_22(int id0);
  public void SetFullScreen(int id0)
    { SetFullScreen_22(id0); }

  private native void WindowRemap_23();
  public void WindowRemap()
    { WindowRemap_23(); }

  private native int GetEventPending_24();
  public int GetEventPending()
    { return GetEventPending_24(); }

  private native void SetNextWindowInfo_25(String id0);
  public void SetNextWindowInfo(String id0)
    { SetNextWindowInfo_25(id0); }

  private native void CreateAWindow_26();
  public void CreateAWindow()
    { CreateAWindow_26(); }

  private native void DestroyWindow_27();
  public void DestroyWindow()
    { DestroyWindow_27(); }

  private native void SetIsDirect_28(int id0);
  public void SetIsDirect(int id0)
    { SetIsDirect_28(id0); }

  private native void SetSupportsOpenGL_29(int id0);
  public void SetSupportsOpenGL(int id0)
    { SetSupportsOpenGL_29(id0); }

  private native void SetIsCurrent_30(boolean id0);
  public void SetIsCurrent(boolean id0)
    { SetIsCurrent_30(id0); }

  private native void Render_31();
  public void Render()
    { Render_31(); }

  private native double GetMaximumHardwareLineWidth_32();
  public double GetMaximumHardwareLineWidth()
    { return GetMaximumHardwareLineWidth_32(); }

  private native void SetForceMaximumHardwareLineWidth_33(double id0);
  public void SetForceMaximumHardwareLineWidth(double id0)
    { SetForceMaximumHardwareLineWidth_33(id0); }

  private native double GetForceMaximumHardwareLineWidthMinValue_34();
  public double GetForceMaximumHardwareLineWidthMinValue()
    { return GetForceMaximumHardwareLineWidthMinValue_34(); }

  private native double GetForceMaximumHardwareLineWidthMaxValue_35();
  public double GetForceMaximumHardwareLineWidthMaxValue()
    { return GetForceMaximumHardwareLineWidthMaxValue_35(); }

  private native double GetForceMaximumHardwareLineWidth_36();
  public double GetForceMaximumHardwareLineWidth()
    { return GetForceMaximumHardwareLineWidth_36(); }

  private native void SetReadyForRendering_37(boolean id0);
  public void SetReadyForRendering(boolean id0)
    { SetReadyForRendering_37(id0); }

  private native boolean GetReadyForRendering_38();
  public boolean GetReadyForRendering()
    { return GetReadyForRendering_38(); }

  public vtkGenericOpenGLRenderWindow() { super(); }

  public vtkGenericOpenGLRenderWindow(long id) { super(id); }
  public native long   VTKInit();

}
